==> baseui-9.106.3.tgz: package/es/list/styled-components.js <==
/*
Copyright (c) 2018-2020 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import { styled, expandBorderStyles } from '../styles/index.js';
import { artworkSizeToValue } from './utils.js';
export const StyledRoot = styled('li', ({
  $theme
}) => {
  return {
    alignItems: 'center',
    backgroundColor: $theme.colors.backgroundPrimary,
    display: 'flex',
    listStyleType: 'none',
    width: '100%'
  };
});
StyledRoot.displayName = "StyledRoot";
export const StyledContent = styled('div', ({
  $mLeft,
  $sublist,
  $theme
}) => {
  return { ...expandBorderStyles($theme.borders.border100),
    alignItems: 'center',
    borderTopStyle: 'none',
    borderRightStyle: 'none',
    borderLeftStyle: 'none',
    display: 'flex',
    flexGrow: 1,
    height: $sublist ? '48px' : '72px',
    justifyContent: 'space-between',
    marginLeft: $mLeft ? $theme.sizing.scale600 : null,
    ...($theme.direction === 'rtl' ? {
      paddingLeft: $theme.sizing.scale600
    } : {
      paddingRight: $theme.sizing.scale600
    })
  };
});
StyledContent.displayName = "StyledContent";
export const StyledEndEnhancerContainer = styled('div', {
  alignItems: 'center',
  display: 'flex'
});
StyledEndEnhancerContainer.displayName = "StyledEndEnhancerContainer";
export const StyledArtworkContainer = styled('div', ({
  $artworkSize,
  $sublist,
  $theme
}) => {
  let sizeValue = typeof $artworkSize === 'number' ? $artworkSize : artworkSizeToValue($artworkSize, Boolean($sublist));

  if (sizeValue > 36) {
    return {
      alignItems: 'center',
      display: 'flex',
      paddingLeft: $theme.sizing.scale600,
      paddingRight: $theme.sizing.scale600
    };
  }

  return {
    alignItems: 'center',
    display: 'flex',
    justifyContent: 'center',
    width: $theme.sizing.scale1600
  };
});
StyledArtworkContainer.displayName = "StyledArtworkContainer";
export const StyledLabelContent = styled('p', ({
  $theme
}) => {
  return { ...$theme.typography.LabelMedium,
    color: $theme.colors.contentPrimary,
    marginTop: 0,
    marginBottom: 0
  };
});
StyledLabelContent.displayName = "StyledLabelContent";
export const StyledLabelDescription = styled('p', ({
  $theme
}) => {
  return { ...$theme.typography.ParagraphSmall,
    color: $theme.colors.contentPrimary,
    marginTop: 0,
    marginBottom: 0
  };
});
StyledLabelDescription.displayName = "StyledLabelDescription";
export const StyledLabelSublistContent = styled('p', ({
  $theme
}) => {
  return { ...$theme.typography.ParagraphMedium,
    color: $theme.colors.contentPrimary
  };
});
StyledLabelSublistContent.displayName = "StyledLabelSublistContent";

==> baseui-9.116.0.tgz: package/es/list/styled-components.js <==
/*
Copyright (c) Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import { styled, expandBorderStyles } from '../styles/index.js';
import { artworkSizeToValue } from './utils.js';
export const StyledRoot = styled('li', ({
  $theme
}) => {
  return {
    alignItems: 'center',
    backgroundColor: $theme.colors.backgroundPrimary,
    display: 'flex',
    listStyleType: 'none',
    width: '100%'
  };
});
StyledRoot.displayName = "StyledRoot";
export const StyledContent = styled('div', ({
  $mLeft,
  $sublist,
  $theme
}) => {
  return { ...expandBorderStyles($theme.borders.border100),
    alignItems: 'center',
    borderTopStyle: 'none',
    borderRightStyle: 'none',
    borderLeftStyle: 'none',
    display: 'flex',
    flexGrow: 1,
    minHeight: $sublist ? '48px' : '72px',
    justifyContent: 'space-between',
    marginLeft: $mLeft ? $theme.sizing.scale600 : null,
    ...($theme.direction === 'rtl' ? {
      paddingLeft: $theme.sizing.scale600
    } : {
      paddingRight: $theme.sizing.scale600
    })
  };
});
StyledContent.displayName = "StyledContent";
export const StyledEndEnhancerContainer = styled('div', {
  alignItems: 'center',
  display: 'flex'
});
StyledEndEnhancerContainer.displayName = "StyledEndEnhancerContainer";
export const StyledArtworkContainer = styled('div', ({
  $artworkSize,
  $sublist,
  $theme
}) => {
  let sizeValue = typeof $artworkSize === 'number' ? $artworkSize : artworkSizeToValue($artworkSize, Boolean($sublist));

  if (sizeValue > 36) {
    return {
      alignItems: 'center',
      display: 'flex',
      paddingLeft: $theme.sizing.scale600,
      paddingRight: $theme.sizing.scale600
    };
  }

  return {
    alignItems: 'center',
    display: 'flex',
    justifyContent: 'center',
    width: $theme.sizing.scale1600
  };
});
StyledArtworkContainer.displayName = "StyledArtworkContainer";
export const StyledLabelContent = styled('p', ({
  $theme
}) => {
  return { ...$theme.typography.LabelMedium,
    color: $theme.colors.contentPrimary,
    marginTop: 0,
    marginBottom: 0
  };
});
StyledLabelContent.displayName = "StyledLabelContent";
export const StyledLabelDescription = styled('p', ({
  $theme
}) => {
  return { ...$theme.typography.ParagraphSmall,
    color: $theme.colors.contentPrimary,
    marginTop: 0,
    marginBottom: 0
  };
});
StyledLabelDescription.displayName = "StyledLabelDescription";
export const StyledLabelSublistContent = styled('p', ({
  $theme
}) => {
  return { ...$theme.typography.ParagraphMedium,
    color: $theme.colors.contentPrimary
  };
});
StyledLabelSublistContent.displayName = "StyledLabelSublistContent";
